//+------------------------------------------------------------------+
//|                                              DoubleInsideBar.mq4 |
//|                                                                  |
//+------------------------------------------------------------------+

/*
Price Bar number 1 is an Inside Bar
Price Bar number 2 is an Inside Bar in relation to Price Bars 3 & 4
The high of Bar 2 is below the high of Bar 3
The low of Bar 2 is above the low of Bar 4


*/   

#property indicator_chart_window
#property indicator_buffers 1
#property indicator_color1 LightBlue

extern string  TimeFrame        = "Current time frame";
extern bool    ArrowsOnFirstBar = true;

double CrossUp[];

string indicatorFileName;
bool   returnBars;
int    timeFrame;


int init()
  {
   SetIndexStyle(0, DRAW_ARROW, EMPTY);
   SetIndexArrow(0, 233);
   SetIndexBuffer(0, CrossUp);
   indicatorFileName = WindowExpertName();
   returnBars        = TimeFrame == "returnBars";     if (returnBars)     return(0);
   timeFrame         = stringToTimeFrame(TimeFrame);
   IndicatorShortName(timeFrameToString(timeFrame)+" Double Inside Bar");
   return(0);
  }


int deinit()
  {
   return(0);
  }


int start() {
   int counted_bars=IndicatorCounted();
      if(counted_bars<0) return(-1);
      if(counted_bars>0) counted_bars--;
           int limit=MathMin(Bars-counted_bars,Bars-1);
           if (returnBars) { CrossUp[0] = limit+1; return(0); }
   
            if (timeFrame!=Period())
            {
               int shift = -1; if (ArrowsOnFirstBar) shift=1;
               limit = MathMax(limit,MathMin(Bars-1,iCustom(NULL,timeFrame,indicatorFileName,"returnBars",0,0)*timeFrame/Period()));
               for (int i=limit; i>=0; i--)
               {
                   int y = iBarShift(NULL,timeFrame,Time[i]);   
                   int x = iBarShift(NULL,timeFrame,Time[i+shift]);            
                   if (x!=y)
                   {
                      CrossUp[i] = iCustom(NULL,timeFrame,indicatorFileName,"calculateValue",0,y);
                   }
               }
               return(0);
            }
   int counter;
   double Range, AvgRange;

   //---- check for possible errors
   if(counted_bars<0) return(-1);

   //---- last counted bar will be recounted
   if(counted_bars>0) counted_bars--;

   limit=Bars-counted_bars;

   for(i = 0; i < limit; i++)
   {
      counter=i;
      Range=0;
      AvgRange=0;
      for (counter=i ;counter<=i+9;counter++)
      {
         AvgRange=AvgRange+MathAbs(High[counter]-Low[counter]);
      }
      Range=AvgRange/10;
      
	   //bar 1 is an inside bar
	   if (High[i+1] < High[i+2] && Low[i+1] > Low[i+2])
	   {
		   //bar 2 is inside relative to bars 3 & 4
			//high of bar 2 is below that of bar 3 && low of bar 2 is above low of bar 4
			CrossUp[i] = EMPTY_VALUE;
			if (High[i+2] < High[i+3] && Low[i+2] > Low[i+4])
         {
            CrossUp[i+1] = Low[i+1] - Range*0.5;
         }
			// OR high of bar 2 is below that of bar 4 && low of bar 2 is above low of bar 3
			if (High[i+2] < High[i+4] && Low[i+2] > Low[i+3])
         {
            CrossUp[i+1] = Low[i+1] - Range*0.5;
         }
	   }
   }
   return(0);
}

//-------------------------------------------------------------------
//
//-------------------------------------------------------------------
//
//
//
//
//

string sTfTable[] = {"M1","M5","M15","M30","H1","H4","D1","W1","MN"};
int    iTfTable[] = {1,5,15,30,60,240,1440,10080,43200};

//
//
//
//
//

int stringToTimeFrame(string tfs)
{
   tfs = stringUpperCase(tfs);
   for (int i=ArraySize(iTfTable)-1; i>=0; i--)
         if (tfs==sTfTable[i] || tfs==""+iTfTable[i]) return(MathMax(iTfTable[i],Period()));
                                                      return(Period());
}
string timeFrameToString(int tf)
{
   for (int i=ArraySize(iTfTable)-1; i>=0; i--) 
         if (tf==iTfTable[i]) return(sTfTable[i]);
                              return("");
}

//
//
//
//
//

string stringUpperCase(string str)
{
   string   s = str;

   for (int length=StringLen(str)-1; length>=0; length--)
   {
      int char = StringGetChar(s, length);
         if((char > 96 && char < 123) || (char > 223 && char < 256))
                     s = StringSetChar(s, length, char - 32);
         else if(char > -33 && char < 0)
                     s = StringSetChar(s, length, char + 224);
   }
   return(s);
}



